aboutsummaryrefslogtreecommitdiff
path: root/src/profiling/DeactivateTimelineReportingCommandHandler.hpp
diff options
context:
space:
mode:
authorCathal Corbett <cathal.corbett@arm.com>2022-02-25 15:33:28 +0000
committerCathal Corbett <cathal.corbett@arm.com>2022-03-01 11:44:14 +0000
commit5aa9fd7ac6bf8dad576fa4a0a32aa3dae98d11ab (patch)
tree23a3a0d5ca5143924277f34c98d36cf7b99430a7 /src/profiling/DeactivateTimelineReportingCommandHandler.hpp
parent1fc448ad2455ad31b96a3891f847125a3295d75a (diff)
downloadarmnn-5aa9fd7ac6bf8dad576fa4a0a32aa3dae98d11ab.tar.gz
IVGCVSW-6704 Change the namespace from armnn::profiling to arm::pipe
* Updated ABI version to 29 due to being the first ABI break in 22.05 !android-nn-driver:7226 Signed-off-by: Cathal Corbett <cathal.corbett@arm.com> Change-Id: I9c50007dcd5b5e792757e7bd1213606df5ffec36
Diffstat (limited to 'src/profiling/DeactivateTimelineReportingCommandHandler.hpp')
-rw-r--r--src/profiling/DeactivateTimelineReportingCommandHandler.hpp9
1 files changed, 5 insertions, 4 deletions
diff --git a/src/profiling/DeactivateTimelineReportingCommandHandler.hpp b/src/profiling/DeactivateTimelineReportingCommandHandler.hpp
index 822e92c425..4d0473ff78 100644
--- a/src/profiling/DeactivateTimelineReportingCommandHandler.hpp
+++ b/src/profiling/DeactivateTimelineReportingCommandHandler.hpp
@@ -7,14 +7,15 @@
#include "ProfilingStateMachine.hpp"
#include "INotifyBackends.hpp"
+#include "ProfilingStateMachine.hpp"
#include <common/include/CommandHandlerFunctor.hpp>
#include <common/include/Packet.hpp>
-namespace armnn
+namespace arm
{
-namespace profiling
+namespace pipe
{
class DeactivateTimelineReportingCommandHandler : public arm::pipe::CommandHandlerFunctor
@@ -41,6 +42,6 @@ private:
INotifyBackends& m_BackendNotifier;
};
-} // namespace profiling
+} // namespace pipe
-} // namespace armnn \ No newline at end of file
+} // namespace arm \ No newline at end of file